pg.ddx.io  pgsql-performance@postgresql.org mailing list archive  
help / color / mirror / Atom feed
From: Knels, Udo <U.Knels@treubuch-it.de>
To: pgsql-performance@postgresql.org <pgsql-performance@postgresql.org>
Subject: Re: Problem with performance using query with unnest after migrating from V9.1 to V9.2 and higher
Date: Thu, 22 Sep 2016 12:39:30 +0000
Message-ID: <de4134e10aa14dbeb7e0850ccfc4ae73@EXCH-1.ddd-do.de> (raw)
In-Reply-To: <283046e4-a37f-d8cb-85dc-52d1286e8ffb@BlueTreble.com>
References: <1d6ce510f1cf4dfcad73b15ff8ff98a4@EXCH-1.ddd-do.de>
	<283046e4-a37f-d8cb-85dc-52d1286e8ffb@BlueTreble.com>
List-Unsubscribe:  <mailto:majordomo@postgresql.org?body=unsub%20pgsql-performance>

Hi,

I tried the following on the upgraded database:
analyze schema_test.table_a;

But the result is the same. 

https://explain.depesz.com/s/hsx5

"Sort  (cost=5.94..6.01 rows=26 width=6) (actual time=0.199..0.200 rows=3 loops=1)"
"  Sort Key: table_a.col0002"
"  Sort Method: quicksort  Memory: 25kB"
"  Buffers: shared hit=1"
"  ->  HashAggregate  (cost=5.07..5.33 rows=26 width=6) (actual time=0.161..0.163 rows=3 loops=1)"
"        Group Key: table_a.col0002"
"        Buffers: shared hit=1"
"        ->  Hash Semi Join  (cost=2.76..4.95 rows=50 width=6) (actual time=0.070..0.133 rows=26 loops=1)"
"              Hash Cond: ((table_a.col0001)::text = (unnest('{5010010000}'::text[])))"
"              Buffers: shared hit=1"
"              ->  Seq Scan on table_a  (cost=0.00..1.50 rows=50 width=17) (actual time=0.015..0.034 rows=50 loops=1)"
"                    Buffers: shared hit=1"
"              ->  Hash  (cost=1.51..1.51 rows=100 width=32) (actual time=0.028..0.028 rows=1 loops=1)"
"                    Buckets: 1024  Batches: 1  Memory Usage: 9kB"
"                    ->  Result  (cost=0.00..0.51 rows=100 width=0) (actual time=0.015..0.017 rows=1 loops=1)"
"Planning time: 0.653 ms"
"Execution time: 0.326 ms"

Greetings

Udo Knels
treubuch IT GmbH



-- 
Sent via pgsql-performance mailing list (pgsql-performance@postgresql.org)
To make changes to your subscription:
http://www.postgresql.org/mailpref/pgsql-performance



view thread (6+ messages)  latest in thread

Message-ID: <de4134e10aa14dbeb7e0850ccfc4ae73@EXCH-1.ddd-do.de>
Permalink:  ../de4134e10aa14dbeb7e0850ccfc4ae73@EXCH-1.ddd-do.de/
Also on:    postgresql.org/message-id/de4134e10aa14dbeb7e0850ccfc4ae73@EXCH-1.ddd-do.de

 · 

reply

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Reply to all the recipients using the --to and --cc options:
  reply via email

  To: pgsql-performance@postgresql.org
  Cc: U.Knels@treubuch-it.de
  Subject: Re: Problem with performance using query with unnest after migrating from V9.1 to V9.2 and higher
  In-Reply-To: <de4134e10aa14dbeb7e0850ccfc4ae73@EXCH-1.ddd-do.de>

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox